==> hdf5_1.10.7+repack.orig.tar.gz: hdf5-1.10.7+repack/java/src/hdf/hdf5lib/exceptions/HDF5AtomException.java <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * Copyright by The HDF Group.                                               *
 * Copyright by the Board of Trustees of the University of Illinois.         *
 * All rights reserved.                                                      *
 *                                                                           *
 * This file is part of HDF5.  The full HDF5 copyright notice, including     *
 * terms governing use, modification, and redistribution, is contained in    *
 * the COPYING file, which can be found at the root of the source code       *
 * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
 * If you do not have access to either file, you may request a copy from     *
 * help@hdfgroup.org.                                                        *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

package hdf.hdf5lib.exceptions;

/**
 * The class HDF5LibraryException returns errors raised by the HDF5 library.
 * <p>
 * This sub-class represents HDF-5 major error code <b>H5E_ATOM</b>
 */

public class HDF5AtomException extends HDF5LibraryException {
    /**
     * Constructs an <code>HDF5AtomException</code> with no specified detail
     * message.
     */
    public HDF5AtomException() {
        super();
    }

    /**
     * Constructs an <code>HDF5AtomException</code> with the specified detail
     * message.
     *
     * @param s
     *            the detail message.
     */
    public HDF5AtomException(String s) {
        super(s);
    }

}

==> hdf5_1.10.10+repack.orig.tar.gz: hdf5-1.10.10+repack/java/src/hdf/hdf5lib/exceptions/HDF5AtomException.java <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * Copyright by The HDF Group.                                               *
 * All rights reserved.                                                      *
 *                                                                           *
 * This file is part of HDF5.  The full HDF5 copyright notice, including     *
 * terms governing use, modification, and redistribution, is contained in    *
 * the COPYING file, which can be found at the root of the source code       *
 * distribution tree, or in https://www.hdfgroup.org/licenses.               *
 * If you do not have access to either file, you may request a copy from     *
 * help@hdfgroup.org.                                                        *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

package hdf.hdf5lib.exceptions;

/**
 * The class HDF5LibraryException returns errors raised by the HDF5 library.
 * <p>
 * This sub-class represents HDF5 major error code <b>H5E_ATOM</b>
 */

public class HDF5AtomException extends HDF5LibraryException {
    /**
     * @ingroup JERRLIB
     *
     * Constructs an <code>HDF5AtomException</code> with no specified detail
     * message.
     */
    public HDF5AtomException() { super(); }

    /**
     * @ingroup JERRLIB
     *
     * Constructs an <code>HDF5AtomException</code> with the specified detail
     * message.
     *
     * @param s
     *            the detail message.
     */
    public HDF5AtomException(String s) { super(s); }
}
